from StringIO import StringIO
from Products.CMFCore.utils import getToolByName


def changeAvailableViews(self, portal_type, templates, out):
    """Add new template(s) view to given portal type"""

    types_tool = getToolByName(self, 'portal_types', None)
    if types_tool is not None:
        fti = getattr(types_tool, portal_type, None)
        if fti is not None:
            try:
                views = fti.view_methods + templates
                fti.manage_changeProperties(view_methods=views)
                print >> out, "Added new view templates to %s FTI." % portal_type
            except:
                print >> out, "Adding new view templates to %s FTI failed." % portal_type


def undoAvailableViews(self, portal_type, templates, out):
    """Undo: Add new template(s) view to given portal type"""

    types_tool = getToolByName(self, 'portal_types', None)
    if types_tool is not None:
        fti = getattr(types_tool, portal_type, None)
        if fti is not None:
            try:
                source = fti.view_methods
                views = []
                for view in source:
                    if view not in templates:
                        views.append(view)                                    
                fti.manage_changeProperties(view_methods=tuple(views))
                print >> out, "Removed view template(s) from %s FTI." % portal_type
            except:
                print >> out, "Removing view template(s) from %s FTI failed." % portal_type


def setupAttachmentWorkflow(context):
    """Turn off workflow for the IBFile type.
    """
    wft = getToolByName(context, 'portal_workflow')
    wft.setChainForPortalTypes(('IBFile', 'IBImage'), ())


def install(self):
    out = StringIO()

    # Install stylesheet
    portal_css = getToolByName(self, 'portal_css')
    portal_css.manage_addStylesheet(id = 'InventoryBuilderStyle.css',
                                    expression = "",
                                    media = 'all',
                                    title = 'InventoryBuilder styles',
                                    enabled = True)


    # Enable portal_factory
    factory = getToolByName(self, 'portal_factory')
    types = factory.getFactoryTypes().keys()
    if 'InventoryBuilder' not in types:
        types.append('InventoryBuilder')
        factory.manage_setPortalFactoryTypes(listOfTypeIds = types)

    if 'IBCategory' not in types:
        types.append('IBCategory')
        factory.manage_setPortalFactoryTypes(listOfTypeIds = types)

    print >> out, "Added InventoryBuilder and IBCategory to portal_factory"


    ctool=getToolByName(self,'portal_catalog')
    new_indexes = [{'iname':'listCategoryIds',
                    'itype':'KeywordIndex'},
                  ]
    # add indexes to portal_catalog. This index stores a list of all categories in which is item assigned
    for index in new_indexes:
        if not index['iname'] in ctool.indexes():
            ctool.addIndex(index['iname'], index['itype'])
            print >> out, "Added %s (%s) index to portal_catalog." % (index['iname'], index['itype'])
       
        if not index['iname'] in ctool.schema():
            ctool.manage_addColumn(index['iname'])
            print >> out, "Added %s metadata to portal_catalog." % index['iname']


    # Set up the workflow for the attachments
    setupAttachmentWorkflow(self)
    print >> out, "Set up IBFile and IBImage workflows."


    propsTool = getToolByName(self, 'portal_properties')
    siteProperties = getattr(propsTool, 'site_properties')
    navProperties = getattr(siteProperties, 'navtree_properties')

    # Add the IBFile and IBImage types to types_not_searched
    # (this is configurable via the Search settings control panel)
    typesNotSearched = list(siteProperties.getProperty('types_not_searched'))
    if 'IBFile' not in typesNotSearched:
        typesNotSearched.append('IBFile')
    if 'IBImage' not in typesNotSearched:
        typesNotSearched.append('IBImage')
    siteProperties.manage_changeProperties(types_not_searched = typesNotSearched)
    print >> out, "Added IBFile and IBImage to types_not_searched."

    # Add the IBCategory, IBItem, IBFile and IBImage types to metaTypesNotToList
    # (this is configurable via the Navigation settings control panel)
    typesNotToList = list(navProperties.getProperty('metaTypesNotToList'))
    if 'IBCategory' not in typesNotToList:
        typesNotToList.append('IBCategory')
    if 'IBItem' not in typesNotToList:
        typesNotToList.append('IBItem')
    if 'IBFile' not in typesNotToList:
        typesNotToList.append('IBFile')
    if 'IBImage' not in typesNotToList:
        typesNotToList.append('IBImage')
    navProperties.manage_changeProperties(metaTypesNotToList = typesNotToList)
    print >> out, "Added IBItem, IBFile and IBImage to metaTypesNotToList."

    # view templates registration
    changeAvailableViews(self, 'Folder', ('inventories_summary_view',), out)

    # Add InventoryBuilder, IBCategory and IBItem to kupu's collection and linkable types
    kupuTool = getToolByName(self, 'kupu_library_tool')
    collection = list(kupuTool.getPortalTypesForResourceType('collection'))
    linkable = list(kupuTool.getPortalTypesForResourceType('linkable'))
    if 'InventoryBuilder' not in collection:
        collection.append('InventoryBuilder')
    if 'IBCategory' not in linkable:
        linkable.append('IBCategory')
    if 'IBItem' not in linkable:
        linkable.append('IBItem')
    # kupu_library_tool has an idiotic interface, basically written purely to
    # work with its configuration page. :-(
    kupuTool.updateResourceTypes(({'resource_type' : 'linkable',
                                   'old_type'      : 'linkable',
                                   'portal_types'  :  linkable},
                                  {'resource_type' : 'collection',
                                   'old_type'      : 'collection',
                                   'portal_types'  :  collection},))
    print >> out, "Added IBCategory and IBItem to kupu's linkable and InventoryBuilder to kupu's collection."

    return out.getvalue()


    
def uninstall(self):
    out = StringIO()

    # grouping template unregistration
    undoAvailableViews(self, 'Folder', ('inventories_summary_view',), out)
    
    return out.getvalue()
