"""Workflow: InventoryBuilder_workflow
"""

# Copyright (c) 2005 by Copyright (c) 2005 SureCase.org Team.
#

# Generator: ArchGenXML Version 1.4.0-RC2 svn/development
#            http://plone.org/products/archgenxml
#
# GNU General Public Licence (GPL)
# 
# This program is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation; either version 2 of the License, or (at your option) any later
# version.
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
# details.
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc., 59 Temple
# Place, Suite 330, Boston, MA  02111-1307  USA
#
__author__    = '''Radim Novotny <info@surecase.org>, Lukas Zdych <unknown>'''
__docformat__ = 'plaintext'
__version__   = '$ Revision 0.0 $'[11:-2]

from Products.CMFCore.utils import getToolByName
from Products.CMFCore.WorkflowTool import addWorkflowFactory
from Products.DCWorkflow.DCWorkflow import DCWorkflowDefinition
from Products.ExternalMethod.ExternalMethod import ExternalMethod

##code-section create-workflow-module-header #fill in your manual code here
##/code-section create-workflow-module-header


productname = 'InventoryBuilder'

def setupInventoryBuilder_workflow(self, workflow):
    """Define the InventoryBuilder_workflow workflow.
    """

    workflow.setProperties(title='InventoryBuilder_workflow')

    ##code-section create-workflow-setup-method-header #fill in your manual code here
    ##/code-section create-workflow-setup-method-header


    for s in ['closed', 'open']:
        workflow.states.addState(s)

    for t in ['close', 'open']:
        workflow.transitions.addTransition(t)

    for v in ['review_history', 'comments', 'time', 'actor', 'action']:
        workflow.variables.addVariable(v)

    for p in ['Inventory Builder: Add category', 'Inventory Builder: Add item', 'Add portal content', 'Access contents information', 'Modify portal content', 'View']:
        workflow.addManagedPermission(p)

    for l in []:
        if not l in workflow.worklists.objectValues():
            workflow.worklists.addWorklist(l)

    ## Initial State

    workflow.states.setInitialState('closed')

    ## States initialization

    stateDef = workflow.states['closed']
    stateDef.setProperties(title="""Closed for posting""",
                           transitions=['open'])
    stateDef.setPermission('Inventory Builder: Add category',
                           0,
                           ['Manager', 'Owner'])
    stateDef.setPermission('Inventory Builder: Add item',
                           0,
                           ['Manager', 'Owner'])
    stateDef.setPermission('Add portal content',
                           0,
                           ['Manager', 'Owner'])
    stateDef.setPermission('Access contents information',
                           0,
                           ['Manager', 'Owner', 'Anonymous'])
    stateDef.setPermission('Modify portal content',
                           0,
                           ['Manager', 'Owner'])
    stateDef.setPermission('View',
                           0,
                           ['Manager', 'Owner', 'Anonymous'])

    stateDef = workflow.states['open']
    stateDef.setProperties(title="""Open for posting""",
                           transitions=['close'])
    stateDef.setPermission('Inventory Builder: Add category',
                           0,
                           ['Manager', 'Owner'])
    stateDef.setPermission('Inventory Builder: Add item',
                           0,
                           ['Manager', 'Owner', 'Member'])
    stateDef.setPermission('Add portal content',
                           0,
                           ['Manager', 'Owner', 'Member'])
    stateDef.setPermission('Access contents information',
                           0,
                           ['Manager', 'Owner', 'Anonymous'])
    stateDef.setPermission('Modify portal content',
                           0,
                           ['Manager', 'Owner'])
    stateDef.setPermission('View',
                           0,
                           ['Manager', 'Owner', 'Anonymous'])

    ## Transitions initialization

    transitionDef = workflow.transitions['close']
    transitionDef.setProperties(title="""Close for posting""",
                                new_state_id="""closed""",
                                trigger_type=1,
                                script_name="""""",
                                after_script_name="""""",
                                actbox_name="""Close for posting""",
                                actbox_url="""""",
                                actbox_category="""workflow""",
                                props={'guard_permissions': 'Review portal content'},
                                )

    transitionDef = workflow.transitions['open']
    transitionDef.setProperties(title="""Open for posting""",
                                new_state_id="""open""",
                                trigger_type=1,
                                script_name="""""",
                                after_script_name="""""",
                                actbox_name="""Open for posting""",
                                actbox_url="""""",
                                actbox_category="""workflow""",
                                props={'guard_permissions': 'Review portal content'},
                                )

    ## State Variable
    workflow.variables.setStateVar('review_state')

    ## Variables initialization
    variableDef = workflow.variables['review_history']
    variableDef.setProperties(description="""Provides access to workflow history""",
                              default_value="""""",
                              default_expr="""state_change/getHistory""",
                              for_catalog=0,
                              for_status=0,
                              update_always=0,
                              props={'guard_permissions': 'Request review; Review portal content'})

    variableDef = workflow.variables['comments']
    variableDef.setProperties(description="""Comments about the last transition""",
                              default_value="""""",
                              default_expr="""python:state_change.kwargs.get('comment', '')""",
                              for_catalog=0,
                              for_status=1,
                              update_always=1,
                              props=None)

    variableDef = workflow.variables['time']
    variableDef.setProperties(description="""Time of the last transition""",
                              default_value="""""",
                              default_expr="""state_change/getDateTime""",
                              for_catalog=0,
                              for_status=1,
                              update_always=1,
                              props=None)

    variableDef = workflow.variables['actor']
    variableDef.setProperties(description="""The ID of the user who performed the last transition""",
                              default_value="""""",
                              default_expr="""user/getId""",
                              for_catalog=0,
                              for_status=1,
                              update_always=1,
                              props=None)

    variableDef = workflow.variables['action']
    variableDef.setProperties(description="""The last transition""",
                              default_value="""""",
                              default_expr="""transition/getId|nothing""",
                              for_catalog=0,
                              for_status=1,
                              update_always=1,
                              props=None)

    ## Worklists Initialization


    # WARNING: below protected section is deprecated.
    # Add a tagged value 'worklist' with the worklist name to your state(s) instead.

    ##code-section create-workflow-setup-method-footer #fill in your manual code here
    ##/code-section create-workflow-setup-method-footer



def createInventoryBuilder_workflow(self, id):
    """Create the workflow for InventoryBuilder.
    """

    ob = DCWorkflowDefinition(id)
    setupInventoryBuilder_workflow(self, ob)
    return ob

addWorkflowFactory(createInventoryBuilder_workflow,
                   id='InventoryBuilder_workflow',
                   title='InventoryBuilder_workflow')

##code-section create-workflow-module-footer #fill in your manual code here
##/code-section create-workflow-module-footer

