###########################################################
# recursivley replaces ALL ocurrences of a string in files
# and optionally in the filenames too.

import re, string

class MultiReplace:

    def __init__(self, repl_dict, no_case=0):

        # "compile" replacement dictionary

        # assume char to char mapping
        charmap = map(chr, range(256))
        for k, v in repl_dict.items():
            if len(k) != 1 or len(v) != 1:
                self.charmap = None
                break
            charmap[ord(k)] = v
        else:
            self.charmap = ''.join(charmap)
            return

        # string to string mapping; use a regular expression
        keys = repl_dict.keys()
        keys.sort() # lexical order
        pattern = '|'.join(map(re.escape, keys))
        self.pattern = re.compile(pattern)
        self.dict = repl_dict


    def replace(self, str):
        # apply replacement dictionary to string
        if self.charmap:
            return string.translate(str, self.charmap)
        def repl(match, get=self.dict.get):
            item = match.group(0)
            return get(item, item)
        return self.pattern.sub(repl, str)


from os.path import walk, isdir, join, split, splitext
from os import rename

def getAllFiles(startDir):
    def visit(result, dirname, names):
        for file in names:
            result.append(join(dirname, file))
    result = []
    walk(startDir, visit, result)
    return result

def replace(startDir, mrDict, changeFileNames=0):
    # replaces ALL ocurrences of a string in both files and filenames
    mr = MultiReplace(mrDict)
    # search and replace in file content
    files = getAllFiles(startDir)
    # need to sort files so that directories in
    # deepest hierachies gets changed first.
    files.sort(lambda x,y: cmp(len(x.split('\\')), len(y.split('\\'))))
    files.reverse()
    for file in files:
        head, tail = split(file)
        fTail, ext = splitext(tail)
        if ext in ('.pt', '.py', '.txt', '.cpt', '.cpy', '.vpy', '.gif', '.metadata', ''):
             # Replace in files
            if not isdir(file):
                f = open(file, 'r+wb')
                content = f.read()
                newContent = mr.replace(content)
                f.seek(0)
                f.write(newContent)
                f.truncate()
                f.close()

            if changeFileNames == 1:
                # Rename filenames
                head, tail = split(file)
                newTail = mr.replace(tail)
                rename(file, join(head, newTail))

if __name__ == '__main__':
    
    from sys import argv, path
#    try:
    old_name = argv[1]
    new_name = argv[2]
    startDir = path[0]
    print 'Search & Replacing to: %s' % new_name
    print 'In directory:', startDir
    replace(startDir, {
            old_name:new_name,
        }, changeFileNames=1)
    print 'Done, please remember to rename the top folder too.'
    print 'I cannot do it from the inside.....'
#    except:
#        print 'Need a name to rename too'
        
