#
# Skeleton PloneTestCase
#

import os, sys
if __name__ == '__main__':
    execfile(os.path.join(sys.path[0], 'framework.py'))

from Products.InventoryBuilder.tests import InventoryBuilderTestCase

class TestIBItem(InventoryBuilderTestCase.InventoryBuilderTestCase):

    def afterSetUp(self):
        InventoryBuilderTestCase.InventoryBuilderTestCase.afterSetUp(self)  # creates inventorybuilder folder with id 'inventorybuilder1'
        self.inventorybuilder1 =  self.portal.inventorybuilder1
        self.inventorybuilder1.invokeFactory('IBCategory',
                                   id='category1',
                                   title='Test Category 1',
                                   description='A Category instance for unit tests.',
                                  )
        self.category1 = getattr(self.inventorybuilder1, 'category1')        
        self.inventorybuilder1.invokeFactory('IBItem',
                                   id='item1',
                                   title='Test Item 1',
                                   description='A Item instance for unit tests.',
                                  )
        self.item1 = getattr(self.inventorybuilder1, 'item1')

    def testItemId(self):
        self.assertEqual(self.item1.getId(), 'item1')

    def testGenerateSku(self):
        self.assertEqual(len(self.item1.generateSku()), 24)

    def testIsItemExpired(self):
        from DateTime import DateTime
        self.item1.setItemExpirationDate(None)  # never expires
        self.assertEqual(self.item1.isItemExpired(), False)
        self.item1.setItemExpirationDate(DateTime()+1)  # set expiration date to future
        self.assertEqual(self.item1.isItemExpired(), False)
        self.item1.setItemExpirationDate(DateTime()-1)  # set expiration date to future
        self.assertEqual(self.item1.isItemExpired(), True)

    def testAddRemoveToFromCategory(self):
        self.assertEqual(self.category1.countItems(), 0)
        self.item1.addToCategory(self.category1)
        self.assertEqual(self.category1.countItems(), 1)
        # do not increase count!
        self.item1.addToCategory(self.category1)
        self.assertEqual(self.category1.countItems(), 1)
        # remove from category
        self.item1.removeFromCategory(self.category1)
        self.assertEqual(self.category1.countItems(), 0)
        # do not raise error
        self.item1.removeFromCategory(self.category1)

    def testListCategories(self):
        self.assertEqual(self.item1.listCategories(), [])
        self.item1.addToCategory(self.category1)
        self.assertEqual(self.item1.listCategories(), [self.category1])
    
    def testFieldExists(self):
        self.assertEqual(self.item1.fieldExists('DuMmY'), False)
        self.assertEqual(self.item1.fieldExists('title'), True)
    
    def testListCategoryIds(self):
        self.item1.addToCategory(self.category1)
        self.assertEqual(self.item1.listCategoryIds(), [self.category1.getId()])
    
    def testParentInventoryBuilder(self):
        self.assertEqual(self.item1.getParentInventoryBuilder(), self.inventorybuilder1)

def test_suite():
    from unittest import TestSuite, makeSuite
    suite = TestSuite()
    suite.addTest(makeSuite(TestIBItem))
    return suite

if __name__ == '__main__':
    framework()

