# File: InventoryBuilder.py
# 
# Copyright (c) 2005 by Copyright (c) 2005 SureCase.org Team.
# Generator: ArchGenXML Version 1.4.0-RC2 svn/development 
#            http://plone.org/products/archgenxml
#
# GNU General Public Licence (GPL)
# 
# This program is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation; either version 2 of the License, or (at your option) any later
# version.
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
# details.
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc., 59 Temple
# Place, Suite 330, Boston, MA  02111-1307  USA
#
__author__  = '''Radim Novotny <info@surecase.org>, Lukas Zdych <unknown>'''
__docformat__ = 'plaintext'


from AccessControl import ClassSecurityInfo
from Products.Archetypes.atapi import *
from Products.ATContentTypes.content.folder import ATFolder
from Products.ATSchemaEditorNG.SchemaEditor import SchemaEditor
from Products.InventoryBuilder.interfaces.IInventoryBuilderBaseObject import IInventoryBuilderBaseObject
from Products.InventoryBuilder.interfaces.IInventoryBuilderObject import IInventoryBuilderObject


# additional imports from tagged value 'import'
from Products.InventoryBuilder.types.IBItem import IBItem
from Products.ATContentTypes.configuration import zconf
from Products.ATContentTypes.lib.validators import *

from Products.InventoryBuilder.config import *
##code-section module-header #fill in your manual code here
if HAS_LINGUA_PLONE:
    from Products.LinguaPlone.public import *

from Products.InventoryBuilder.util import SQLStorage, filterContents
from Products.CMFCore.utils import getToolByName
from Products.Archetypes.public import DisplayList
from Products.DataGridField import DataGridField, DataGridWidget
from Products.ATSchemaEditorNG.config import ATSE_MANAGED_FULL, ATSE_MANAGED_NONE
##/code-section module-header

schema=Schema((
    TextField('text',
        widget=RichWidget(
            description="Enter title text for this catalog.",
            rows=25,
            label="Title text",
            label_msgid='InventoryBuilder_label_text',
            description_msgid='InventoryBuilder_help_text',
            i18n_domain='InventoryBuilder',
        ),
        default_content_type=zconf.ATDocument.default_content_type,
        searchable=True,
        required=False,
        storage=AnnotationStorage(migrate=True),
        primary=False,
        allowable_content_types=zconf.ATDocument.allowed_content_types,
        validators=('isTidyHtmlWithCleanup',),
        allow_file_upload=zconf.ATDocument.allow_document_upload,
        default_output_type="text/x-html-safe"
    ),

    IntegerField('categories_listing_columns',
        default=2,
        schemata="UI",
        widget=IntegerWidget(
            label="Categories columns",
            description="Enter number of columns to show inventorybuilder categories in.",
            label_msgid='InventoryBuilder_label_categories_listing_columns',
            description_msgid='InventoryBuilder_help_categories_listing_columns',
            i18n_domain='InventoryBuilder',
        ),
        languageIndependent=True,
        storage=AnnotationStorage(migrate=True)
    ),

    IntegerField('last_items_columns',
        default=2,
        schemata="UI",
        widget=IntegerWidget(
            label="Last items columns",
            description="Enter number of columns to show last items in on title page of the inventorybuilder.",
            label_msgid='InventoryBuilder_label_last_items_columns',
            description_msgid='InventoryBuilder_help_last_items_columns',
            i18n_domain='InventoryBuilder',
        ),
        languageIndependent=True,
        storage=AnnotationStorage(migrate=True)
    ),

    IntegerField('last_items_count',
        default=4,
        schemata="UI",
        widget=IntegerWidget(
            label="Last items count",
            description="Enter number of last items to be shown on title page of the inventorybuilder.",
            label_msgid='InventoryBuilder_label_last_items_count',
            description_msgid='InventoryBuilder_help_last_items_count',
            i18n_domain='InventoryBuilder',
        ),
        languageIndependent=True,
        storage=AnnotationStorage(migrate=True)
    ),

    IntegerField('items_per_page',
        default=20,
        schemata="UI",
        widget=IntegerWidget(
            label="Items per page",
            description="Enter number of items which will be displayed per page in category listing table by default (it can be temporarely changed by visitor during browsing the inventorybuilder).",
            label_msgid='InventoryBuilder_label_items_per_page',
            description_msgid='InventoryBuilder_help_items_per_page',
            i18n_domain='InventoryBuilder',
        ),
        languageIndependent=True,
        storage=AnnotationStorage(migrate=True)
    ),

    BooleanField('use_categories',
        default=True,
        widget=BooleanWidget(
            label="Use Categories",
            description="If this option is checked, the button for creating categories  will be displayed on inventorybuilder title page.",
            label_msgid='InventoryBuilder_label_use_categories',
            description_msgid='InventoryBuilder_help_use_categories',
            i18n_domain='InventoryBuilder',
        ),
        languageIndependent=True,
        schemata="UI",
        accessor="allowCategories"
    ),

    LinesField('display_images',
        widget=InAndOutWidget
        (
            label="Display Images",
            description="If this option is checked and inventory items contains images (not attachments), the images will be displayed in last items table.",
            label_msgid='InventoryBuilder_label_display_images',
            description_msgid='InventoryBuilder_help_display_images',
            i18n_domain='InventoryBuilder',
        ),
        languageIndependent=True,
        schemata="UI",
        mode="rw",
        vocabulary="getAvailableImageFields",
        default=VOC_DISPLAY_IMAGES,
        enforceVocabulary=1,
        required=False
    ),

    BooleanField('display_counts',
        widget=BooleanWidget(
            label="Display Counts",
            description="If this option is checked there will be displayed counts of contained items inside categories and subcategories. It is not recomended to use this feature for large inventories because of performance cost.",
            label_msgid='InventoryBuilder_label_display_counts',
            description_msgid='InventoryBuilder_help_display_counts',
            i18n_domain='InventoryBuilder',
        ),
        languageIndependent=True,
        schemata="Settings"
    ),

    StringField('items_layout',
        widget=SelectionWidget(
            label="Items Layout",
            description="Select one of the list of templates which will be used as default view for items posted in this inventory.",
            label_msgid='InventoryBuilder_label_items_layout',
            description_msgid='InventoryBuilder_help_items_layout',
            i18n_domain='InventoryBuilder',
        ),
        languageIndependent=True,
        schemata="Settings",
        vocabulary="getAvailableItemLayouts",
        default="inventorybuilderitem_view",
        enforceVocabulary=1,
        required=True
    ),

    LinesField('listing_table_columns',
        widget=InAndOutWidget
        (
            label="Listing Table Columns",
            description="Select one or more fields of IBItem, which should be displayed in the categories listing table.",
            label_msgid='InventoryBuilder_label_listing_table_columns',
            description_msgid='InventoryBuilder_help_listing_table_columns',
            i18n_domain='InventoryBuilder',
        ),
        languageIndependent=True,
        schemata="Settings",
        mode="rw",
        vocabulary="getAvailableItemFields",
        default=VOC_LISTING_COLUMNS,
        enforceVocabulary=1,
        required=False
    ),

    LinesField('protected_fields',
        widget=InAndOutWidget
        (
            label="Protected Fields",
            description="Select one or more fields from items schemata which will be visible only for users with trusted roles.",
            label_msgid='InventoryBuilder_label_protected_fields',
            description_msgid='InventoryBuilder_help_protected_fields',
            i18n_domain='InventoryBuilder',
        ),
        languageIndependent=True,
        schemata="Settings",
        mode="rw",
        vocabulary="getAvailableItemFields",
        enforceVocabulary=1,
        required=False
    ),

    LinesField('trusted_roles',
        widget=InAndOutWidget
        (
            label="Trusted Roles",
            description="Select security roles which will be allowed to see fields selected as protected.",
            label_msgid='InventoryBuilder_label_trusted_roles',
            description_msgid='InventoryBuilder_help_trusted_roles',
            i18n_domain='InventoryBuilder',
        ),
        languageIndependent=True,
        schemata="Settings",
        mode="rw",
        vocabulary="getAvailableRoles",
        enforceVocabulary=1,
        required=False
    ),

    LinesField('allowed_html_tags',
        default=DEFAULT_ALLOWED_HTML_TAGS,
        schemata="Settings",
        widget=LinesWidget(
            label="Allowed HTML tags (not yet implemented)",
            description="Enter list of HTML tags which can be used in Advertisement's body. Define each tag on it's own line please.",
            label_msgid='InventoryBuilder_label_allowed_html_tags',
            description_msgid='InventoryBuilder_help_allowed_html_tags',
            i18n_domain='InventoryBuilder',
        ),
        languageIndependent=True,
        storage=AnnotationStorage(migrate=True)
    ),

    StringField('cover_string',
        widget=StringWidget(
            label="Cover string (not yet implemented)",
            description="Enter string which will be used to replace bannded words founded in values of choosen IBItem's fields.",
            label_msgid='InventoryBuilder_label_cover_string',
            description_msgid='InventoryBuilder_help_cover_string',
            i18n_domain='InventoryBuilder',
        ),
        languageIndependent=False,
        schemata="Masking",
        default="***",
        storage=AnnotationStorage(migrate=True),
        accessor="coverString"
    ),

    DataGridField('banned_words',
        widget=DataGridWidget
        (
            label="Banned words (not yet implemented)",
            description="Enter list of words which will be replaced by 'cover string' in values of choosen InventoryBuilder item's fields.",
            label_msgid='InventoryBuilder_label_banned_words',
            description_msgid='InventoryBuilder_help_banned_words',
            i18n_domain='InventoryBuilder',
        ),
        languageIndependent=False,
        schemata="Masking",
        storage=AnnotationStorage(migrate=True),
        accessor="bannedWords",
        columns=('word', 'replacement')
    ),

    TextField('help_category_view',
        widget=RichWidget(
            label="Category view help",
            description="Enter text which will be displayed on top of the category view as users help.",
            rows=15,
            label_msgid='InventoryBuilder_label_help_category_view',
            description_msgid='InventoryBuilder_help_help_category_view',
            i18n_domain='InventoryBuilder',
        ),
        default_content_type=zconf.ATDocument.default_content_type,
        searchable=False,
        required=False,
        storage=AnnotationStorage(migrate=True),
        primary=False,
        allowable_content_types=zconf.ATDocument.allowed_content_types,
        schemata="Help",
        validators=('isTidyHtmlWithCleanup',),
        allow_file_upload=zconf.ATDocument.allow_document_upload,
        default_output_type="text/x-html-safe"
    ),

    StringField('help_cat_view_pos',
        widget=SelectionWidget(
            label="Category view help position",
            description="Select positioning of the help text.",
            label_msgid='InventoryBuilder_label_help_cat_view_pos',
            description_msgid='InventoryBuilder_help_help_cat_view_pos',
            i18n_domain='InventoryBuilder',
        ),
        languageIndependent=False,
        schemata="Help",
        vocabulary=VOC_HELP_POSITIONS,
        default_method="getDefHelpPos",
        storage=AnnotationStorage(migrate=True)
    ),

    TextField('help_category_edit',
        widget=RichWidget(
            label="Category edit help",
            description="Enter text which will be displayed on top of the category edit form as users help.",
            rows=15,
            label_msgid='InventoryBuilder_label_help_category_edit',
            description_msgid='InventoryBuilder_help_help_category_edit',
            i18n_domain='InventoryBuilder',
        ),
        default_content_type=zconf.ATDocument.default_content_type,
        searchable=False,
        required=False,
        storage=AnnotationStorage(migrate=True),
        primary=False,
        allowable_content_types=zconf.ATDocument.allowed_content_types,
        schemata="Help",
        validators=('isTidyHtmlWithCleanup',),
        allow_file_upload=zconf.ATDocument.allow_document_upload,
        default_output_type="text/x-html-safe"
    ),

    StringField('help_cat_edit_pos',
        widget=SelectionWidget(
            label="Category edit help position",
            description="Select positioning of the help text.",
            label_msgid='InventoryBuilder_label_help_cat_edit_pos',
            description_msgid='InventoryBuilder_help_help_cat_edit_pos',
            i18n_domain='InventoryBuilder',
        ),
        languageIndependent=False,
        schemata="Help",
        vocabulary=VOC_HELP_POSITIONS,
        default_method="getDefHelpPos",
        storage=AnnotationStorage(migrate=True)
    ),

    TextField('help_item_view',
        widget=RichWidget(
            label="Item view help",
            description="Enter text which will be displayed on top of the item view as users help.",
            rows=15,
            label_msgid='InventoryBuilder_label_help_item_view',
            description_msgid='InventoryBuilder_help_help_item_view',
            i18n_domain='InventoryBuilder',
        ),
        default_content_type=zconf.ATDocument.default_content_type,
        searchable=False,
        required=False,
        storage=AnnotationStorage(migrate=True),
        primary=False,
        allowable_content_types=zconf.ATDocument.allowed_content_types,
        schemata="Help",
        validators=('isTidyHtmlWithCleanup',),
        allow_file_upload=zconf.ATDocument.allow_document_upload,
        default_output_type="text/x-html-safe"
    ),

    StringField('help_item_view_pos',
        widget=SelectionWidget(
            label="Item view help position",
            description="Select positioning of the help text.",
            label_msgid='InventoryBuilder_label_help_item_view_pos',
            description_msgid='InventoryBuilder_help_help_item_view_pos',
            i18n_domain='InventoryBuilder',
        ),
        languageIndependent=False,
        schemata="Help",
        vocabulary=VOC_HELP_POSITIONS,
        default_method="getDefHelpPos",
        storage=AnnotationStorage(migrate=True)
    ),

    TextField('help_item_edit',
        widget=RichWidget(
            label="Item edit help",
            description="Enter text which will be displayed on top of the item edit form as users help.",
            rows=15,
            label_msgid='InventoryBuilder_label_help_item_edit',
            description_msgid='InventoryBuilder_help_help_item_edit',
            i18n_domain='InventoryBuilder',
        ),
        default_content_type=zconf.ATDocument.default_content_type,
        searchable=False,
        required=False,
        storage=AnnotationStorage(migrate=True),
        primary=False,
        allowable_content_types=zconf.ATDocument.allowed_content_types,
        schemata="Help",
        validators=('isTidyHtmlWithCleanup',),
        allow_file_upload=zconf.ATDocument.allow_document_upload,
        default_output_type="text/x-html-safe"
    ),

    StringField('help_item_edit_pos',
        widget=SelectionWidget(
            label="Item edit help position",
            description="Select positioning of the help text.",
            label_msgid='InventoryBuilder_label_help_item_edit_pos',
            description_msgid='InventoryBuilder_help_help_item_edit_pos',
            i18n_domain='InventoryBuilder',
        ),
        languageIndependent=False,
        schemata="Help",
        vocabulary=VOC_HELP_POSITIONS,
        default_method="getDefHelpPos",
        storage=AnnotationStorage(migrate=True)
    ),

),
)


##code-section after-local-schema #fill in your manual code here
##/code-section after-local-schema

InventoryBuilder_schema = getattr(ATFolder,'schema',Schema(())) + \
    getattr(SchemaEditor,'schema',Schema(())) + \
    schema

##code-section after-schema #fill in your manual code here

# the key under which the schema is stored and retrieved
# (this is usually the portal_type of the client class
SCHEMA_ID = 'IBItem'

##/code-section after-schema

class InventoryBuilder(ATFolder,SchemaEditor):
    security = ClassSecurityInfo()
    __implements__ = (getattr(ATFolder,'__implements__',()),) + (getattr(SchemaEditor,'__implements__',()),) + (IInventoryBuilderBaseObject,IInventoryBuilderObject,)


    # This name appears in the 'add' box
    archetype_name             = 'Inventory'

    meta_type                  = 'InventoryBuilder'
    portal_type                = 'InventoryBuilder'
    allowed_content_types      = ['IBCategory', 'IBItem'] + list(getattr(ATFolder, 'allowed_content_types', [])) + list(getattr(SchemaEditor, 'allowed_content_types', []))
    filter_content_types       = 1
    global_allow               = 1
    allow_discussion           = 0
    content_icon               = 'inventorybuilder_icon.gif'
    immediate_view             = 'inventorybuilder_view'
    default_view               = 'inventorybuilder_view'
    suppl_views                = ()
    typeDescription            = "Inventory"
    typeDescMsgId              = 'description_edit_inventorybuilder'

    actions =  (


       {'action':      "string:${object_url}/inventorybuilder_view",
        'category':    "object",
        'id':          'view',
        'name':        'View',
        'permissions': (VIEW_PERMISSION,),
        'condition'  : 'python:1'
       },


       {'action':      "string:${object_url}/inventorybuilder_edit",
        'category':    "object",
        'id':          'edit',
        'name':        'Edit',
        'permissions': (EDIT_PERMISSION,),
        'condition'  : 'python:1'
       },


       {'action':      "string:${object_url}/sharing",
        'category':    "object",
        'id':          'sharing',
        'name':        'sharing',
        'permissions': (EDIT_PERMISSION,),
        'condition'  : 'python:1'
       },


       {'action':      "string:${object_url}/inventorybuilder_schema_editor",
        'category':    "object",
        'id':          'attributes',
        'name':        'Attributes',
        'permissions': (EDIT_PERMISSION,),
        'condition'  : 'python:1'
       },


    )

    schema = InventoryBuilder_schema

    ##code-section class-header #fill in your manual code here
    _at_rename_after_creation = True
    ##/code-section class-header


    #Methods

    security.declareProtected(EDIT_PERMISSION, 'manage_afterAdd')
    def manage_afterAdd(self,item,container):
        """ post creation (or post renaming) actions """
        
        # do not show metadata fieldset
        self.atse_registerObject(IBItem,
                                 ('metadata', ), # filtered_schemas
                                 ('id', # undeleteable_fields
                                  'title',
                                  'description',
                                  'relatedItems',
                                  ),
                                 ('default',  # undeleteable_schematas
                                  ),
                                 'InventoryBuilder') # domain
        # self.schema_editor_tool.atse_registerObject( IBItem, ('metadata', ))
        ATFolder.manage_afterAdd(self, item, container)
        # self._migrateObjPtype()

        # enable InventoryBuilder syndication by default
        syn_tool = getToolByName(self, 'portal_syndication', None)
        if syn_tool is not None:
            if syn_tool.isSiteSyndicationAllowed():
                if not syn_tool.isSyndicationAllowed(self):
                    syn_tool.enableSyndication(self)



    security.declareProtected(VIEW_PERMISSION, 'CookedBody')
    def CookedBody(self, field, stx_level='ignored'):
        """
        """

        return self.getField(field).get(self)



    security.declareProtected(VIEW_PERMISSION, 'getAllowed_types')
    def getAllowed_types(self):
        """
        Returns [] just for compatibility with IBCategory.
        """

        return []



    security.declareProtected(EDIT_PERMISSION, 'getDefHelpPos')
    def getDefHelpPos(self):
        """
        Return default views help position.
        """

        return VOC_HELP_POSITIONS.getKey('Bottom')



    security.declareProtected(VIEW_PERMISSION, 'isFieldLink')
    def isFieldLink(self, value):
        """
        Return True if value is hypertext link.
        """

        import re
        protocols = ['ftp', 'news', 'irc', 'h323', 'sip', 'callto', 'https', 'http', 'file']

        for protocol in protocols:
            rE = re.compile(r"\A%s://" % protocol, re.I)
            res = rE.search(value)
            if res != None:
                return True

        return False



    security.declareProtected(VIEW_PERMISSION, 'isFieldMail')
    def isFieldMail(self, value):
        """
        Return True if value is email address.
        """

        import re
        rE = re.compile(r"\A[a-z0-9_.\-]+@[a-z0-9_.\-]+.[a-z0-9_.\-]+", re.I)
        res = rE.match(value)
        if res != None:
            return True

        return False



    security.declareProtected(EDIT_PERMISSION, 'getAvailableItemFields')
    def getAvailableItemFields(self):
        """
        Return all available IBItem fields which can be displayed
        in InventoryBuilderCategories listing tables.
        """

        results = DisplayList()

        fields = []
        # dunno how to get all managed fields directly without struggling with 'schematas'
        for schemata in self.atse_getSchemataNames('IBItem'):
            fields.extend(self.atse_getSchemata('IBItem', schemata).fields())

        for field in fields:
            if field.widget.visible['view'] not in ('invisible', 'hidden'):
                key = field.getName()
                results.add(key, field.widget.label,'inventorybuilder' + key)

        return results



    security.declareProtected(VIEW_PERMISSION, 'getNiceHTMLTags')
    def getNiceHTMLTags(self):
        """
        Returns allowed HTML tags in nice format.
        """
        tags = self.getAllowed_html_tags()
        
        return ', '.join(['<%s>' % tag for tag in tags])
    


    security.declarePrivate('synContentValues')
    def synContentValues(self):
        """
        Getter for syndacation support
        """

        syn_tool = getToolByName(self, 'portal_syndication', None)
        cnt = syn_tool.getMaxItems() or None
        return self.getInventoryBuilderLastItems(rev_state = 'public', count = cnt)



    security.declareProtected(VIEW_PERMISSION, 'getInventoryBuilderLastItems')
    def getInventoryBuilderLastItems(self, rev_state=None, count=None):
        """
        Returns list of last items in current inventorybuilder folder.
        """

        query = {'path':'/'.join(self.getPhysicalPath()),
                 'sort_on':'Date',
                 'sort_order':'reverse',
                 }

        if count == None:
            count = self.getLast_items_count()

        if rev_state != None:
            query['review_state'] = rev_state

        schemas = self._schemas.items()
        ptypes = []
        for schema in schemas:
            ptypes.append(schema[0])

        if len(ptypes) > 0:
            query['portal_type'] = ptypes
            
        iCatalog = getToolByName(self, 'portal_catalog')
        results = iCatalog(**query)[:count]
        
        return results



    security.declareProtected(EDIT_PERMISSION, 'getAvailableImageFields')
    def getAvailableImageFields(self):
        """
        Return all available (visible) fields of 'image' type.
        """

        results = DisplayList()
        fields = []

        # dunno how to get all managed fields directly without struggling with 'schematas'
        for schemata in self.atse_getSchemataNames('IBItem'):
            fields.extend(self.atse_getSchemata('IBItem', schemata).fields())

        for field in fields:
            if field.type == 'image':
                if field.widget.visible['view'] not in ('invisible', 'hidden'):
                    key = field.getName()
                    results.add(key, field.widget.label,'inventorybuilder' + key)

        return results
    


    security.declareProtected(EDIT_PERMISSION, 'getAvailableItemLayouts')
    def getAvailableItemLayouts(self):
        """
        Return available supplied views for IBItem registered for it in portal_types.
        """

        portal_type = 'IBItem'

        ptool = getToolByName(self, 'portal_types')
        availTypes = ptool.listTypeTitles()

        result = DisplayList()

        if portal_type in availTypes:
            availViews = ptool[portal_type].getAvailableViewMethods(self)
            for view in availViews:
                result.add(view, view)

        return result



    security.declareProtected(EDIT_PERMISSION, 'getAvailableRoles')
    def getAvailableRoles(self):
        """
        Return DisplayList instance with all exiting security roles in portal.
        """

        result = DisplayList()
        roles = self.validRoles()
        for role in roles:
            result.add(role, role)

        return result
        

    #methods from Interface IInventoryBuilderBaseObject

    security.declareProtected(VIEW_PERMISSION, 'getParentInventoryBuilder')
    def getParentInventoryBuilder(self):
        """
        Return self as InventoryBuilder.
        """
        
        return self



    security.declareProtected(VIEW_PERMISSION, 'getDisplayValue')
    def getDisplayValue(self, obj, fieldname, key):
        """
        Returns vocabulary title from given object, fieldname and key.
        """
        
        field = obj.getField(fieldname)
        if not key:
            key = field.get(obj)
            
            if key and key!='undefined':
                vocab = field.Vocabulary(obj)
                msgid = vocab.getMsgId(key)
                return translate(msgid=msgid, default=vocab.getValue(key), domain='InventoryBuilder')
            else:
                return ''



    security.declareProtected(VIEW_PERMISSION, 'listAttachments')
    def listAttachments(self):
        """
        
        """
        
        pass



    security.declareProtected(VIEW_PERMISSION, 'getBuildInImages')
    def getBuildInImages(self):
        """
        
        """
        
        pass



    security.declareProtected(VIEW_PERMISSION, 'formatMultiSelectionValue')
    def formatMultiSelectionValue(self):
        """
        
        """
        
        pass



    security.declareProtected(VIEW_PERMISSION, 'validateFieldAccess')
    def validateFieldAccess(self):
        """
        
        """
        
        pass


    #methods from Interface IInventoryBuilderObject

    security.declareProtected(VIEW_PERMISSION, 'listCategories')
    def listCategories(self):
        """
        Returns list of IBCategory objects inside itself.
        """
        return self.listFolderContents(contentFilter={'portal_type':'IBCategory'})
    


    security.declareProtected(VIEW_PERMISSION, 'getContents')
    def getContents(self,filter = {}):
       """
       Return a list of objects that are registered inside the category. The
       result could be filtered using a dictionary, where the keys are object
       properties and the values are acceptable values for these keys.
       """
        
       return filterContents(self.getBRefs("category"), filter)



    security.declareProtected(VIEW_PERMISSION, 'countItems')
    def countItems(self):
        """
        Return grand count of items in folder (category) and it's contents.
        """

        count = len(self.listFolderContents(contentFilter={'portal_type':'IBItem'}))
        return count



registerType(InventoryBuilder,PROJECTNAME)
# end of class InventoryBuilder

##code-section module-footer #fill in your manual code here
##/code-section module-footer



